==> haskell-http-streams-0.8.9.9-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-LEg7qH1m2WE7KJqNSHFsEX
key:                  http-streams-0.8.9.9-LEg7qH1m2WE7KJqNSHFsEX
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  f958b40165dd41d17912cb31906146dc
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-LEg7qH1m2WE7KJqNSHFsEX
depends:
    HsOpenSSL-0.11.7.9-7GHIB2Mkk3dAUqn8ip9pbx
    aeson-2.1.2.1-JT1gbb2shwLLy3Tf1UBGhr
    attoparsec-0.14.4-L7VTmm7vDKMCukUYiUxbnG
    attoparsec-aeson-2.1.0.0-CQJJUHeppojBEfAfM1NDvw base-4.17.2.1
    base64-bytestring-1.2.1.0-Cj0eto8WUwBEGc4bOF7Sr3
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LMolnZwpRvW7BfRj8XMS7A directory-1.3.7.1
    filepath-1.4.2.2 http-common-0.8.3.4-3iY846lXO1iFKekrDGITXo
    io-streams-1.5.2.2-69spncpRgMJ1zRAV3gQCdG mtl-2.2.2
    network-3.1.4.0-Ghv3vyYrUARFMXgpkYG5Ga
    network-uri-2.6.4.2-JjmDvpdn2VAKjLknJxWVBO
    openssl-streams-1.2.3.0-2RNWfCdqEXBLOCw6JEfuoQ text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-GHxywVRZMTgDKQfzKfhJsl

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.9.9-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-HCjF8Cih0KwE3qD2RVkHcR
key:                  http-streams-0.8.9.9-HCjF8Cih0KwE3qD2RVkHcR
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  9abc1629ace01d1f07f5a567b8ca761c
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-HCjF8Cih0KwE3qD2RVkHcR
depends:
    HsOpenSSL-0.11.7.9-7GHIB2Mkk3dAUqn8ip9pbx
    aeson-2.1.2.1-JT1gbb2shwLLy3Tf1UBGhr
    attoparsec-0.14.4-L7VTmm7vDKMCukUYiUxbnG
    attoparsec-aeson-2.1.0.0-CQJJUHeppojBEfAfM1NDvw base-4.17.2.1
    base64-bytestring-1.2.1.0-Cj0eto8WUwBEGc4bOF7Sr3
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LMolnZwpRvW7BfRj8XMS7A directory-1.3.7.1
    filepath-1.4.2.2 http-common-0.8.3.4-3iY846lXO1iFKekrDGITXo
    io-streams-1.5.2.2-69spncpRgMJ1zRAV3gQCdG mtl-2.2.2
    network-3.1.4.0-Ghv3vyYrUARFMXgpkYG5Ga
    network-uri-2.6.4.2-JjmDvpdn2VAKjLknJxWVBO
    openssl-streams-1.2.3.0-2RNWfCdqEXBLOCw6JEfuoQ text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-GHxywVRZMTgDKQfzKfhJsl

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
